
#==============================================================================#
# exerb/version.rb
# $Id: version.rb,v 1.10 2003/02/21 05:14:48 yuya Exp $
#==============================================================================#

#==============================================================================#
# Exerb Module
module Exerb

  VERSION = '2.6.2'

end # Exerb

#==============================================================================#
#==============================================================================#
